# This file is generated by objective.metadata
#
# Last update: Thu Nov 12 21:49:11 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$VNAnimalDetectorCat$VNAnimalDetectorDog$VNAnimalIdentifierCat$VNAnimalIdentifierDog$VNBarcodeSymbologyAztec$VNBarcodeSymbologyCode128$VNBarcodeSymbologyCode39$VNBarcodeSymbologyCode39Checksum$VNBarcodeSymbologyCode39FullASCII$VNBarcodeSymbologyCode39FullASCIIChecksum$VNBarcodeSymbologyCode93$VNBarcodeSymbologyCode93i$VNBarcodeSymbologyDataMatrix$VNBarcodeSymbologyEAN13$VNBarcodeSymbologyEAN8$VNBarcodeSymbologyI2of5$VNBarcodeSymbologyI2of5Checksum$VNBarcodeSymbologyITF14$VNBarcodeSymbologyPDF417$VNBarcodeSymbologyQR$VNBarcodeSymbologyUPCE$VNBodyLandmarkKeyLeftAnkle$VNBodyLandmarkKeyLeftEar$VNBodyLandmarkKeyLeftElbow$VNBodyLandmarkKeyLeftEye$VNBodyLandmarkKeyLeftHip$VNBodyLandmarkKeyLeftKnee$VNBodyLandmarkKeyLeftShoulder$VNBodyLandmarkKeyLeftWrist$VNBodyLandmarkKeyNeck$VNBodyLandmarkKeyNose$VNBodyLandmarkKeyRightAnkle$VNBodyLandmarkKeyRightEar$VNBodyLandmarkKeyRightElbow$VNBodyLandmarkKeyRightEye$VNBodyLandmarkKeyRightHip$VNBodyLandmarkKeyRightKnee$VNBodyLandmarkKeyRightShoulder$VNBodyLandmarkKeyRightWrist$VNBodyLandmarkKeyRoot$VNBodyLandmarkRegionKeyFace$VNBodyLandmarkRegionKeyLeftArm$VNBodyLandmarkRegionKeyLeftLeg$VNBodyLandmarkRegionKeyRightArm$VNBodyLandmarkRegionKeyRightLeg$VNBodyLandmarkRegionKeyTorso$VNErrorDomain$VNHandLandmarkKeyIndexDIP$VNHandLandmarkKeyIndexMCP$VNHandLandmarkKeyIndexPIP$VNHandLandmarkKeyIndexTIP$VNHandLandmarkKeyLittleDIP$VNHandLandmarkKeyLittleMCP$VNHandLandmarkKeyLittlePIP$VNHandLandmarkKeyLittleTIP$VNHandLandmarkKeyMiddleDIP$VNHandLandmarkKeyMiddleMCP$VNHandLandmarkKeyMiddlePIP$VNHandLandmarkKeyMiddleTIP$VNHandLandmarkKeyRingDIP$VNHandLandmarkKeyRingMCP$VNHandLandmarkKeyRingPIP$VNHandLandmarkKeyRingTIP$VNHandLandmarkKeyThumbCMC$VNHandLandmarkKeyThumbIP$VNHandLandmarkKeyThumbMP$VNHandLandmarkKeyThumbTIP$VNHandLandmarkKeyWrist$VNHandLandmarkRegionKeyIndexFinger$VNHandLandmarkRegionKeyLittleFinger$VNHandLandmarkRegionKeyMiddleFinger$VNHandLandmarkRegionKeyRingFinger$VNHandLandmarkRegionKeyThumb$VNHumanBodyPoseObservationJointNameLeftAnkle$VNHumanBodyPoseObservationJointNameLeftEar$VNHumanBodyPoseObservationJointNameLeftElbow$VNHumanBodyPoseObservationJointNameLeftEye$VNHumanBodyPoseObservationJointNameLeftHip$VNHumanBodyPoseObservationJointNameLeftKnee$VNHumanBodyPoseObservationJointNameLeftShoulder$VNHumanBodyPoseObservationJointNameLeftWrist$VNHumanBodyPoseObservationJointNameNeck$VNHumanBodyPoseObservationJointNameNose$VNHumanBodyPoseObservationJointNameRightAnkle$VNHumanBodyPoseObservationJointNameRightEar$VNHumanBodyPoseObservationJointNameRightElbow$VNHumanBodyPoseObservationJointNameRightEye$VNHumanBodyPoseObservationJointNameRightHip$VNHumanBodyPoseObservationJointNameRightKnee$VNHumanBodyPoseObservationJointNameRightShoulder$VNHumanBodyPoseObservationJointNameRightWrist$VNHumanBodyPoseObservationJointNameRoot$VNHumanBodyPoseObservationJointsGroupNameAll$VNHumanBodyPoseObservationJointsGroupNameFace$VNHumanBodyPoseObservationJointsGroupNameLeftArm$VNHumanBodyPoseObservationJointsGroupNameLeftLeg$VNHumanBodyPoseObservationJointsGroupNameRightArm$VNHumanBodyPoseObservationJointsGroupNameRightLeg$VNHumanBodyPoseObservationJointsGroupNameTorso$VNHumanHandPoseObservationJointNameIndexDIP$VNHumanHandPoseObservationJointNameIndexMCP$VNHumanHandPoseObservationJointNameIndexPIP$VNHumanHandPoseObservationJointNameIndexTip$VNHumanHandPoseObservationJointNameLittleDIP$VNHumanHandPoseObservationJointNameLittleMCP$VNHumanHandPoseObservationJointNameLittlePIP$VNHumanHandPoseObservationJointNameLittleTip$VNHumanHandPoseObservationJointNameMiddleDIP$VNHumanHandPoseObservationJointNameMiddleMCP$VNHumanHandPoseObservationJointNameMiddlePIP$VNHumanHandPoseObservationJointNameMiddleTip$VNHumanHandPoseObservationJointNameRingDIP$VNHumanHandPoseObservationJointNameRingMCP$VNHumanHandPoseObservationJointNameRingPIP$VNHumanHandPoseObservationJointNameRingTip$VNHumanHandPoseObservationJointNameThumbCMC$VNHumanHandPoseObservationJointNameThumbIP$VNHumanHandPoseObservationJointNameThumbMP$VNHumanHandPoseObservationJointNameThumbTip$VNHumanHandPoseObservationJointNameWrist$VNHumanHandPoseObservationJointsGroupNameAll$VNHumanHandPoseObservationJointsGroupNameIndexFinger$VNHumanHandPoseObservationJointsGroupNameLittleFinger$VNHumanHandPoseObservationJointsGroupNameMiddleFinger$VNHumanHandPoseObservationJointsGroupNameRingFinger$VNHumanHandPoseObservationJointsGroupNameThumb$VNImageOptionCIContext$VNImageOptionCameraIntrinsics$VNImageOptionProperties$VNNormalizedIdentityRect@{CGRect={CGPoint=dd}{CGSize=dd}}$VNRecognizedPointGroupKeyAll$VNVideoProcessingOptionFrameCadence$VNVideoProcessingOptionTimeInterval$VNVisionVersionNumber@d$"""
enums = """$VNClassifyImageRequestRevision1@1$VNCoreMLRequestRevision1@1$VNDetectAnimalRectanglesRequestRevision1@1$VNDetectBarcodesRequestRevision1@1$VNDetectContourRequestRevision1@1$VNDetectFaceCaptureQualityRequestRevision1@1$VNDetectFaceCaptureQualityRequestRevision2@2$VNDetectFaceLandmarksRequestRevision1@1$VNDetectFaceLandmarksRequestRevision2@2$VNDetectFaceLandmarksRequestRevision3@3$VNDetectFaceQualityRequestRevision1@1$VNDetectFaceRectanglesRequestRevision1@1$VNDetectFaceRectanglesRequestRevision2@2$VNDetectHorizonRequestRevision1@1$VNDetectHumanBodyPoseRequestRevision1@1$VNDetectHumanHandPoseRequestRevision1@1$VNDetectHumanRectanglesRequestRevision1@1$VNDetectRectanglesRequestRevision1@1$VNDetectTextRectanglesRequestRevision1@1$VNDetectTrajectoriesRequestRevision1@1$VNElementTypeDouble@2$VNElementTypeFloat@1$VNElementTypeUnknown@0$VNErrorDataUnavailable@17$VNErrorIOError@6$VNErrorInternalError@9$VNErrorInvalidArgument@14$VNErrorInvalidFormat@2$VNErrorInvalidImage@13$VNErrorInvalidModel@15$VNErrorInvalidOperation@12$VNErrorInvalidOption@5$VNErrorMissingOption@7$VNErrorNotImplemented@8$VNErrorOK@0$VNErrorOperationFailed@3$VNErrorOutOfBoundsError@4$VNErrorOutOfMemory@10$VNErrorRequestCancelled@1$VNErrorTimeStampNotFound@18$VNErrorUnknownError@11$VNErrorUnsupportedRevision@16$VNGenerateAttentionBasedSaliencyImageRequestRevision1@1$VNGenerateImageFeaturePrintRequestRevision1@1$VNGenerateObjectnessBasedSaliencyImageRequestRevision1@1$VNGenerateOpticalFlowRequestComputationAccuracyHigh@2$VNGenerateOpticalFlowRequestComputationAccuracyLow@0$VNGenerateOpticalFlowRequestComputationAccuracyMedium@1$VNGenerateOpticalFlowRequestComputationAccuracyVeryHigh@3$VNGenerateOpticalFlowRequestRevision1@1$VNHomographicImageRegistrationRequestRevision1@1$VNImageCropAndScaleOptionCenterCrop@0$VNImageCropAndScaleOptionScaleFill@2$VNImageCropAndScaleOptionScaleFit@1$VNRecognizeAnimalsRequestRevision1@1$VNRecognizeTextRequestRevision1@1$VNRecognizeTextRequestRevision2@2$VNRequestFaceLandmarksConstellation65Points@1$VNRequestFaceLandmarksConstellation76Points@2$VNRequestFaceLandmarksConstellationNotDefined@0$VNRequestRevisionUnspecified@0$VNRequestTextRecognitionLevelAccurate@0$VNRequestTextRecognitionLevelFast@1$VNRequestTrackingLevelAccurate@0$VNRequestTrackingLevelFast@1$VNTrackObjectRequestRevision1@1$VNTrackObjectRequestRevision2@2$VNTrackRectangleRequestRevision1@1$VNTranslationalImageRegistrationRequestRevision1@1$"""
misc.update({})
functions = {
    "VNImageRectForNormalizedRect": (
        b"{CGRect={CGPoint=dd}{CGSize=dd}}{CGRect={CGPoint=dd}{CGSize=dd}}QQ",
    ),
    "VNNormalizedPointForImagePoint": (b"{CGPoint=dd}{CGPoint=dd}QQ",),
    "VNNormalizedRectIsIdentityRect": (b"B{CGRect={CGPoint=dd}{CGSize=dd}}",),
    "VNNormalizedRectForImageRect": (
        b"{CGRect={CGPoint=dd}{CGSize=dd}}{CGRect={CGPoint=dd}{CGSize=dd}}QQ",
    ),
    "VNImagePointForNormalizedPoint": (b"{CGPoint=dd}{CGPoint=dd}QQ",),
    "VNElementTypeSize": (b"QQ",),
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"NSObject", b"indeterminate", {"required": True, "retval": {"type": "Z"}})
    r(
        b"NSObject",
        b"inputFaceObservations",
        {"required": True, "retval": {"type": b"@"}},
    )
    r(
        b"NSObject",
        b"progressHandler",
        {
            "required": True,
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": b"d"},
                        3: {"type": b"@"},
                    },
                },
                "type": "@?",
            },
        },
    )
    r(b"NSObject", b"requestRevision", {"required": True, "retval": {"type": "Q"}})
    r(
        b"NSObject",
        b"setInputFaceObservations:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"setProgressHandler:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"d"},
                            3: {"type": b"@"},
                        },
                    },
                    "type": "@?",
                }
            },
        },
    )
    r(b"VNCircle", b"containsPoint:", {"retval": {"type": b"Z"}})
    r(
        b"VNCircle",
        b"containsPoint:inCircumferentialRingOfWidth:",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"VNClassificationObservation",
        b"hasMinimumPrecision:forRecall:",
        {"retval": {"type": "Z"}},
    )
    r(
        b"VNClassificationObservation",
        b"hasMinimumRecall:forPrecision:",
        {"retval": {"type": "Z"}},
    )
    r(
        b"VNClassifyImageRequest",
        b"knownClassificationsForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNContour",
        b"childContourAtIndex:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNContour",
        b"polygonApproximationWithEpsilon:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNContoursObservation",
        b"contourAtIndex:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNContoursObservation",
        b"contourAtIndexPath:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNCoreMLModel",
        b"modelForMLModel:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNCoreMLRequest",
        b"initWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNCoreMLRequest",
        b"initWithModel:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"VNDetectContoursRequest", b"detectDarkOnLight", {"retval": {"type": b"Z"}})
    r(b"VNDetectContoursRequest", b"detectsDarkOnLight", {"retval": {"type": b"Z"}})
    r(
        b"VNDetectContoursRequest",
        b"setDetectDarkOnLight:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"VNDetectContoursRequest",
        b"setDetectsDarkOnLight:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"VNDetectFaceLandmarksRequest",
        b"revision:supportsConstellation:",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"VNDetectHumanBodyPoseRequest",
        b"supportedIdentifiedPointGroupKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanBodyPoseRequest",
        b"supportedIdentifiedPointKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanBodyPoseRequest",
        b"supportedJointNamesForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanBodyPoseRequest",
        b"supportedJointsGroupNamesForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanBodyPoseRequest",
        b"supportedRecognizedPointGroupKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanBodyPoseRequest",
        b"supportedRecognizedPointKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanHandPoseRequest",
        b"supportedIdentifiedPointGroupKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanHandPoseRequest",
        b"supportedIdentifiedPointKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanHandPoseRequest",
        b"supportedJointNamesForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanHandPoseRequest",
        b"supportedJointsGroupNamesForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanHandPoseRequest",
        b"supportedRecognizedPointGroupKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectHumanHandPoseRequest",
        b"supportedRecognizedPointKeysForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNDetectTextRectanglesRequest",
        b"reportCharacterBoxes",
        {"retval": {"type": "Z"}},
    )
    r(
        b"VNDetectTextRectanglesRequest",
        b"setReportCharacterBoxes:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"VNDetectTrajectoriesRequest",
        b"initWithFrameAnalysisSpacing:completionHandler:",
        {
            "arguments": {
                2: {"type": b"{_CMTime=qiIq}"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"VNDetectTrajectoriesRequest",
        b"initWithFrameAnalysisSpacing:trajectoryLength:completionHandler:",
        {
            "arguments": {
                2: {"type": b"{_CMTime=qiIq}"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"VNFaceLandmarkRegion2D",
        b"normalizedPoints",
        {"retval": {"c_array_of_variable_length": True}},
    )
    r(
        b"VNFaceLandmarkRegion2D",
        b"pointsInImageOfSize:",
        {"retval": {"c_array_of_variable_length": True}},
    )
    r(
        b"VNFeaturePrintObservation",
        b"computeDistance:toFeaturePrintObservation:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNGeometryUtils",
        b"boundingCircleForContour:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNGeometryUtils",
        b"boundingCircleForPoints:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNGeometryUtils",
        b"boundingCircleForSIMDPoints:pointCount:error:",
        {
            "arguments": {
                2: {"type_modifier": b"n", "c_array_length_in_arg": 3},
                4: {"type_modifier": b"o"},
            }
        },
    )
    r(
        b"VNGeometryUtils",
        b"calculateArea:forContour:orientedArea:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {
                2: {"type_modifier": b"n"},
                4: {"type": b"Z"},
                5: {"type_modifier": b"o"},
            },
        },
    )
    r(
        b"VNGeometryUtils",
        b"calculatePerimeter:forContour:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {2: {"type_modifier": b"n"}, 4: {"type_modifier": b"o"}},
        },
    )
    r(
        b"VNHumanBodyPoseObservation",
        b"recognizedPointForJointName:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNHumanBodyPoseObservation",
        b"recognizedPointsForJointsGroupName:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNHumanHandPoseObservation",
        b"recognizedPointForJointName:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNHumanHandPoseObservation",
        b"recognizedPointsForJointsGroupName:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNImageHomographicAlignmentObservation",
        b"setWarpTransform:",
        {"arguments": {2: {"type": b"{_matrix_float3x3=?}"}}},
    )
    r(
        b"VNImageHomographicAlignmentObservation",
        b"warpTransform",
        {"retval": {"type": b"{_matrix_float3x3=?}"}},
    )
    r(
        b"VNImageRequestHandler",
        b"performRequests:error:",
        {"retval": {"type": "Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNObservation",
        b"timeRange",
        {"retval": {"type": b"{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}"}},
    )
    r(
        b"VNRecognizeAnimalsRequest",
        b"knownAnimalIdentifiersForRevision:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNRecognizeTextRequest",
        b"setUsesLanguageCorrection:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"VNRecognizeTextRequest",
        b"supportedRecognitionLanguagesForTextRecognitionLevel:revision:error:",
        {"arguments": {4: {"type_modifier": b"o"}}},
    )
    r(b"VNRecognizeTextRequest", b"usesLanguageCorrection", {"retval": {"type": "Z"}})
    r(
        b"VNRecognizedPointsObservation",
        b"identifiedPointsForGroupKey_error_",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNRecognizedPointsObservation",
        b"keypointsMultiArrayAndReturnError:",
        {"arguments": {2: {"type_modifier": b"o"}}},
    )
    r(
        b"VNRecognizedPointsObservation",
        b"recognizedPointForKey:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNRecognizedPointsObservation",
        b"recognizedPointsForGroupKey:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNRecognizedText",
        b"boundingBoxForRange:error:",
        {"arguments": {3: {"type_modifier": b"o"}}},
    )
    r(
        b"VNRequest",
        b"completionHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {
                        0: {"type": b"^v"},
                        1: {"type": b"@"},
                        2: {"type": b"@"},
                    },
                }
            }
        },
    )
    r(
        b"VNRequest",
        b"initWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"VNRequest", b"preferBackgroundProcessing", {"retval": {"type": "Z"}})
    r(
        b"VNRequest",
        b"setPreferBackgroundProcessing:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(b"VNRequest", b"setUsesCPUOnly:", {"arguments": {2: {"type": "Z"}}})
    r(b"VNRequest", b"usesCPUOnly", {"retval": {"type": "Z"}})
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCGImage:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCGImage:orientation:error:",
        {"retval": {"type": "Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCIImage:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCIImage:orientation:error:",
        {"retval": {"type": "Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCMSampleBuffer:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCMSampleBuffer:orientation:error:",
        {"retval": {"type": b"Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCVPixelBuffer:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onCVPixelBuffer:orientation:error:",
        {"retval": {"type": "Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onImageData:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onImageData:orientation:error:",
        {"retval": {"type": "Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onImageURL:error:",
        {"retval": {"type": "Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNSequenceRequestHandler",
        b"performRequests:onImageURL:orientation:error:",
        {"retval": {"type": "Z"}, "arguments": {5: {"type_modifier": b"o"}}},
    )
    r(
        b"VNStatefulRequest",
        b"frameAnalysisSpacing",
        {"retval": {"type": b"{_CMTime=qiIq}"}},
    )
    r(
        b"VNStatefulRequest",
        b"initWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"@?"},
                        "arguments": {0: {"type": b"^v"}},
                    }
                }
            }
        },
    )
    r(
        b"VNStatefulRequest",
        b"initWithFrameAnalysisSpacing:completionHandler:",
        {
            "arguments": {
                2: {"type": b"{_CMTime=qiIq}"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                },
            }
        },
    )
    r(
        b"VNStatefulRequest",
        b"requestFrameAnalysisSpacing",
        {"retval": {"type": b"{_CMTime=qiIq}"}},
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCGImage:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCGImage:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCGImage:orientation:options:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCIImage:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCIImage:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCIImage:orientation:options:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCMSampleBuffer:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCMSampleBuffer:orientation:options:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCVPixelBuffer:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCVPixelBuffer:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedCVPixelBuffer:orientation:options:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedImageData:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedImageData:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedImageData:orientation:options:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedImageURL:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedImageURL:options:completionHandler:",
        {
            "arguments": {
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTargetedImageRequest",
        b"initWithTargetedImageURL:orientation:options:completionHandler:",
        {
            "arguments": {
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTrackObjectRequest",
        b"initWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTrackObjectRequest",
        b"initWithDetectedObjectObservation:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTrackRectangleRequest",
        b"initWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTrackRectangleRequest",
        b"initWithRectangleObservation:completionHandler:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"VNTrackingRequest",
        b"initWithCompletionHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"VNTrackingRequest", b"isLastFrame", {"retval": {"type": "Z"}})
    r(b"VNTrackingRequest", b"setLastFrame:", {"arguments": {2: {"type": "Z"}}})
    r(
        b"VNVideoProcessor",
        b"addRequest:processingOptions:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNVideoProcessor",
        b"addRequest:withProcessingOptions:error:",
        {"retval": {"type": b"Z"}, "arguments": {4: {"type_modifier": b"o"}}},
    )
    r(
        b"VNVideoProcessor",
        b"analyzeTimeRange:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {
                2: {"type": b"{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}"},
                3: {"type_modifier": b"o"},
            },
        },
    )
    r(
        b"VNVideoProcessor",
        b"analyzeWithTimeRange:error:",
        {
            "retval": {"type": b"Z"},
            "arguments": {
                2: {"type": b"{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}"},
                3: {"type_modifier": b"o"},
            },
        },
    )
    r(
        b"VNVideoProcessor",
        b"removeRequest:error:",
        {"retval": {"type": b"Z"}, "arguments": {3: {"type_modifier": b"o"}}},
    )
    r(b"null", b"hasMinimumPrecision:forRecall:", {"retval": {"type": b"Z"}})
    r(b"null", b"hasMinimumRecall:forPrecision:", {"retval": {"type": b"Z"}})
    r(b"null", b"hasPrecisionRecallCurve", {"retval": {"type": b"Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
